@@ -1,8 +1,6 @@
 /*
  * keyboard.h	Constants to talk to the keyboard driver.
  *
- * 		$Id: keyboard.h,v 1.2 2007-10-10 20:18:20 al-guest Exp $
- *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
  *
@@ -21,19 +19,15 @@
 #define KMINIX		5
 #define KSTART		6
 #define KKPAPP		7
-#define KCURST  	8
+#define KCURST		8
 #define KCURAPP		9
 #define KSIGIO		10
 #define KSETESC		11
 #define KSETBS		12
 #define KGETKEY		13
 
-#if defined (_COHERENT) && !defined(SIGUSR1)
-#  define SIGUSR1 SIGDIVE
-#  define SIGUSR2 SIGOVFL
-#endif
 #define HELLO		SIGUSR1
 #define ACK		SIGUSR2
 
-#define KINSTALL 	100
+#define KINSTALL	100
 #define KUNINSTALL	101
